# Modeling: Business Capabilities (Meta Model v3)
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/business-capabilities-modeling-v3#overview)
  * [Resources](https://help.sap.com/docs/leanix/ea/business-capabilities-modeling-v3#resources)


In this section, you will find a best-practice business capability model to upload into your workspace.
